
#include "rjoac.h"

namespace motions {
    RandomJumpOnCone::RandomJumpOnCone(const double delta, const double eta, const double chi, std::mt19937_64 &rng) : BaseMotion("RJ on a Cone", delta, eta, rng), m_angle(chi) {}
    RandomJumpOnCone::RandomJumpOnCone(std::mt19937_64 &rng) : BaseMotion("RJ on a Cone", rng) {}

    void RandomJumpOnCone::initialize() {
        m_axis = draw_position();
    }

    double RandomJumpOnCone::jump() {
        const double phi = 2 * M_PI * m_uni_dist(m_rng);
        return omega_q(coordinates::rotate(m_axis, m_angle, phi));
    }

    void RandomJumpOnCone::setParameters(const std::unordered_map<std::string, double> &parameters) {
        BaseMotion::setParameters(parameters);
        m_angle = parameters.at("angle");
    }

    std::unordered_map<std::string, double> RandomJumpOnCone::getParameters() const {
        auto parameter =  BaseMotion::getParameters();
        parameter["angle"] = m_angle;

        return parameter;
    }

    std::string RandomJumpOnCone::toString() const {
        return std::string("RandomJumpOnCone/angle=") + std::to_string(m_angle);
    }
}